@@ -11,7 +11,7 @@ int32_t SPVM__Sys__Socket__In6_addr__new(SPVM_ENV* env, SPVM_VALUE* stack) {
   
   struct in6_addr* address = env->new_memory_stack(env, stack, sizeof(struct in6_addr));
 
-  void* obj_address = env->new_pointer_by_name(env, stack, "Sys::Socket::In6_addr", address, &e, FILE_NAME, __LINE__);
+  void* obj_address = env->new_pointer_by_name(env, stack, "Sys::Socket::In6_addr", address, &e, __func__, FILE_NAME, __LINE__);
   if (e) { return e; }
   
   stack[0].oval = obj_address;
@@ -59,13 +59,13 @@ int32_t SPVM__Sys__Socket__In6_addr__set_s6_addr(SPVM_ENV* env, SPVM_VALUE* stac
   void* obj_s6_addr = stack[1].oval;
   
   if (!obj_s6_addr) {
-    return env->die(env, stack, "The address must be defined", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The address must be defined", __func__, FILE_NAME, __LINE__);
   }
   
   int32_t s6_addr_length = env->length(env, stack, obj_s6_addr);
   
   if (!(s6_addr_length < 16)) {
-    return env->die(env, stack, "The length of the address must be less than 16", FILE_NAME, __LINE__);
+    return env->die(env, stack, "The length of the address must be less than 16", __func__, FILE_NAME, __LINE__);
   }
   
   const char* chp_s6_addr = env->get_chars(env, stack, obj_s6_addr);
